time_over_threshold

Function time_over_threshold 

pub fn time_over_threshold(
    voltages: &Vec<f32>,
    times: &Vec<f32>,
    threshold: f32,
) -> (f32, f32)
Calculate the time in ns for which the waveform is above a certain threshold for paddle end A

Retunrs:

time over threshold in ns, slope (+- 2bins around crossin)